"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LaneDiff = void 0;
const lane_id_1 = require("@teambit/lane-id");
const lane_component_diff_1 = require("./lane-component-diff");
class LaneDiff {
    constructor(sourceLane, diff, targetLane) {
        this.sourceLane = sourceLane;
        this.diff = diff;
        this.targetLane = targetLane;
    }
    /**
     * count components that are up to date.
     */
    countUpToDate() {
        const upToDate = this.diff.filter((status) => status.upToDate);
        return upToDate.length;
    }
    /**
     * list the components behind.
     */
    behind() {
        return this.diff.filter((status) => !status.upToDate);
    }
    /**
     * list the components that are up to date.
     */
    upToDate() {
        return this.diff.filter((status) => status.upToDate);
    }
    /**
     * count how many components are behind their target.
     */
    countBehind() {
        return this.behind().length;
    }
    /**
     * determines whether component is up to date.
     */
    isUpToDate(ids = []) {
        const strIds = ids === null || ids === void 0 ? void 0 : ids.map((id) => id.toString());
        const componentDiffs = strIds.length
            ? this.diff.filter((componentDiff) => strIds.includes(componentDiff.componentId.toString()))
            : this.diff;
        return componentDiffs.every((status) => {
            return status.upToDate;
        });
    }
    listOutOfDate(ids) {
        const strIds = ids === null || ids === void 0 ? void 0 : ids.map((id) => id.toString());
        const componentDiffs = strIds
            ? this.diff.filter((componentDiff) => strIds.includes(componentDiff.componentId.toString()))
            : this.diff;
        return componentDiffs.filter((status) => {
            return !status.upToDate;
        });
    }
    get new() {
        return this.diff.filter((diff) => diff.new);
    }
    get changed() {
        return this.diff.filter((diff) => diff.changed);
    }
    toObject() {
        var _a;
        return {
            sourceLane: this.sourceLane.toString(),
            targetLane: (_a = this.targetLane) === null || _a === void 0 ? void 0 : _a.toString(),
            diff: this.diff.map((componentDiff) => componentDiff.toObject()),
        };
    }
    static from(laneComponentDiff) {
        const laneComponentDiffList = laneComponentDiff.diff.map((componentDiff) => lane_component_diff_1.LaneComponentDiff.from(componentDiff));
        return new LaneDiff(lane_id_1.LaneId.parse(laneComponentDiff.sourceLane), laneComponentDiffList, (laneComponentDiff === null || laneComponentDiff === void 0 ? void 0 : laneComponentDiff.targetLane) ? lane_id_1.LaneId.parse(laneComponentDiff.targetLane) : undefined);
    }
}
exports.LaneDiff = LaneDiff;
//# sourceMappingURL=lane-diff.js.map